@@ -5,8 +5,9 @@ class Currency(Object):
     def __init__(self, *args, **kwargs):
         super(Currency, self).__init__(*args, **kwargs)
 
-    def round(self, value, decimals=0):
-        multiplier = 10 ** decimals
+    @staticmethod
+    def round(value, decimals=0):
+        multiplier = float(10 ** decimals)
 
         return int(value * multiplier) / multiplier
 
