@@ -140,5 +140,9 @@ def get_cash_salons_countries():
     return get_apiclient().services.shop.get_cash_salons_countries()
 
 
+def get_cash_salons_by_id(salon_id):
+    return get_apiclient().services.shop.get_cash_salons_by_id(salon_id)
+
+
 def get_cash_salons_by_city(city_id):
     return get_apiclient().services.shop.get_cash_salons_by_city(city_id)
