@@ -45,6 +45,25 @@ def reset_password(email):
     return get_apiclient().services.users.reset_password(email)
 
 
+def social_list():
+    return get_apiclient().services.users.social_list()
+
+
+def social_login(token):
+    return get_apiclient().services.users.social_login(token)
+
+
+def social_related():
+    return get_apiclient().services.users.social_related()
+
+
+def social_signin(service, redirect_success, redirect_fail):
+    return get_apiclient().services.users.social_signin(
+        service,
+        redirect_success,
+        redirect_fail)
+
+
 def update_info(
         password=None,
         name=None,
